//@line 36 "/builds/slave/rel-m-192-lnx-rpk-6/l10n-mozilla-1.9.2/sq/browser/firefox-l10n.js"

//@line 38 "/builds/slave/rel-m-192-lnx-rpk-6/l10n-mozilla-1.9.2/sq/browser/firefox-l10n.js"

pref("general.useragent.locale", "sq");
